@@ -208,7 +208,12 @@ void FBReader::initWindow() {
 	}
 	refreshWindow();
 
+#ifdef MAEMO_VERSION
+	// Update clock once a minute on Maemo, to save battery power
+	ZLTimeManager::instance().addTask(new TimeUpdater(*this), 60000);
+#else
 	ZLTimeManager::instance().addTask(new TimeUpdater(*this), 1000);
+#endif
 }
 
 bool FBReader::createDescription(const std::string& fileName, BookDescriptionPtr &description) {
